==> syncope-2.1.2-source-release.zip: syncope-2.1.2/ext/flowable/flowable-bpmn/src/main/java/org/apache/syncope/core/flowable/task/FlowableServiceTask.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.syncope.core.flowable.task;

import org.flowable.engine.delegate.DelegateExecution;
import org.flowable.engine.delegate.JavaDelegate;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

/**
 * Abstract base class for Flowable's service tasks in Syncope, with Spring support.
 */
@Component
public abstract class FlowableServiceTask implements JavaDelegate {

    protected static final Logger LOG = LoggerFactory.getLogger(FlowableServiceTask.class);

    @Transactional(rollbackFor = { Throwable.class })
    @Override
    public void execute(final DelegateExecution execution) {
        doExecute(execution);
    }

    protected abstract void doExecute(final DelegateExecution execution);
}

==> syncope-3.0.15-source-release.zip: syncope-3.0.15/ext/flowable/flowable-bpmn/src/main/java/org/apache/syncope/core/flowable/task/FlowableServiceTask.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.syncope.core.flowable.task;

import org.flowable.engine.delegate.DelegateExecution;
import org.flowable.engine.delegate.JavaDelegate;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.transaction.annotation.Transactional;

/**
 * Abstract base class for Flowable's service tasks in Syncope, with Spring support.
 */
public abstract class FlowableServiceTask implements JavaDelegate {

    protected static final Logger LOG = LoggerFactory.getLogger(FlowableServiceTask.class);

    @Transactional(rollbackFor = { Throwable.class })
    @Override
    public void execute(final DelegateExecution execution) {
        doExecute(execution);
    }

    protected abstract void doExecute(DelegateExecution execution);
}
